/*

  Munipack


  Copyright © 2009-2017 F.Hroch (hroch@physics.muni.cz)

  This file is part of Munipack.

  Munipack is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  Munipack is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with Munipack.  If not, see <http://www.gnu.org/licenses/>.

*/

#include "../config.h"

#define EMAIL PACKAGE_BUGREPORT
#define XVERSION PACKAGE_VERSION
#define INFOTEXT PACKAGE_NAME
#define HOMEPAGE PACKAGE_URL

#define COPYLEFT L"© 1997-2017 " EMAIL

#ifdef DEVELBUILD
#define DVERSION "\n  DEVELOPMENT VERSION (build: " DATEBUILD ")"
#else
#define DVERSION ""
#endif

#define INFOTEXTFULL "A general astronomical image processing software\n" DVERSION
